@@ -10,8 +10,7 @@
 #' Squiggle, respectively.
 #'
 #' @inheritParams fetch_ladder
-#' @return
-#' A Tibble with the fixture from the relevant `season` and `round`.
+#' @return A Tibble with the fixture from the relevant `season` and `round`.
 #' @export
 #'
 #' @examples
@@ -80,31 +79,43 @@ fetch_fixture_afl <- function(season = NULL, round_number = NULL, comp = "AFLM")
     rnd_msg <- paste0("Round ", round_number, ", ", season)
   }
 
-  cli_id <- cli::cli_process_start("Returning data for {.val {rnd_msg}}")
+  cli::cli_progress_step("Returning data for {.val {rnd_msg}}")
   comp_seas_id <- find_season_id(season, comp)
   comp_id <- find_comp_id(comp)
 
-  # Make request
-  api <- "https://aflapi.afl.com.au//afl/v2/matches"
-  resp <- httr::GET(
-    url = api,
-    query = list(
-      "competitionId" = comp_id,
-      "compSeasonId" = comp_seas_id,
-      "roundNumber" = round_number,
-      "pageSize" = "1000"
+  match_request <- function(comp_seas_id, comp_id, round_number) {
+    # Make request
+    api <- "https://aflapi.afl.com.au//afl/v2/matches"
+    resp <- httr::GET(
+      url = api,
+      query = list(
+        "competitionId" = comp_id,
+        "compSeasonId" = comp_seas_id,
+        "roundNumber" = round_number,
+        "pageSize" = "1000"
+      )
     )
-  )
-
-  cont <- resp %>%
-    httr::content(as = "text") %>%
-    jsonlite::fromJSON(flatten = TRUE)
-
-  df <- dplyr::as_tibble(cont$matches) %>%
-    dplyr::mutate(compSeason.year = as.numeric(gsub("([0-9]+).*$", "\\1", .data$compSeason.name))) %>%
+    
+    cont <- resp %>%
+      httr::content(as = "text", encoding = "UTF-8") %>%
+      jsonlite::fromJSON(flatten = TRUE)
+    
+    df <- dplyr::as_tibble(cont$matches)
+    
+  }
+  
+  df <- comp_seas_id %>%
+    purrr::map_dfr(match_request, comp_id, round_number)
+  
+  if (is.null(df) | nrow(df) == 0) {
+    return(df)
+  }
+  
+  df <- df %>%
+    dplyr::mutate(compSeason.year = as.numeric(gsub("^.*([0-9]{4}).*", "\\1", .data$compSeason.name))) %>%
     dplyr::filter(.data$compSeason.year == season)
-
-  cli::cli_process_done(cli_id)
+  
+  #cli::cli_process_done(cli_id)
   return(df)
 }
 
