@@ -14,7 +14,7 @@ test_that("fetch_fixture_afl works for various inputs", {
   # change round number
   expect_s3_class(fetch_fixture_afl(2020, round_number = 1), "tbl")
   expect_s3_class(fetch_fixture_afl(2020, round_number = 2), "tbl")
-  expect_error(fetch_fixture_afl(2020, round_number = 50))
+  expect_s3_class(fetch_fixture_afl(2020, round_number = 50), "tbl")
 
   # change comp
   expect_s3_class(fetch_fixture_afl(2020, round_number = 1, comp = "AFLW"), "tbl")
@@ -159,3 +159,16 @@ test_that("round numbers don't increment across bye weeks without matches", {
   expect_warning(fixture_rounds <- get_fixture(2019)$Round)
   expect_equal(calculate_max_round_lag(fixture_rounds), 1)
 })
+
+test_that("fetch_fixture works for non-AFL leagues", {
+  testthat::skip_if_offline()
+  testthat::skip_on_cran()
+  
+  # Test each source works
+  expect_s3_class(fetch_fixture(2022, round_number = 1, source = "AFL", comp = "WAFL"), "tbl")
+  expect_s3_class(fetch_fixture(2022, round_number = 1, source = "AFL", comp = "VFL"), "tbl")
+  expect_s3_class(fetch_fixture(2022, round_number = 1, source = "AFL", comp = "VFLW"), "tbl")
+  expect_s3_class(fetch_fixture(2022, round_number = 1, source = "AFL", comp = "U18B"), "tbl")
+  expect_s3_class(fetch_fixture(2022, round_number = 1, source = "AFL", comp = "U18G"), "tbl")
+  
+})
\ No newline at end of file
